# emass_client

EmassClient - the Ruby gem for the Enterprise Mission Assurance Support Service (eMASS)

The Enterprise Mission Assurance Support Service (eMASS) Representational State Transfer (REST) Application Programming Interface (API) enables users to perform assessments and complete actions associated with system records.   The `emasser` is a command-line interface (CLI) tool that implements all of the  eMASS endpoints defined in the eMASS REST API v3.2, dated October 21, 2021.</br><br>  <strong>Register CLI</strong></br> New users will need to register an API key with the eMASS development team prior to accessing the site for the first time. The eMASS REST API requires a client certificate (SSL/TLS, DoD PKI only) where {url}/api/register (POST) is used to register the client certificate.</br></br>  Every call to the eMASS REST API will require the use of the agreed upon public key certificate and API key. The API key must be provided in the request header for all endpoint calls (api-key). If the service receives an untrusted certificate or API key, a 401 error response code will be returned along with an error message.</br></br>  <strong>Available Request Headers:</strong></br> <table>   <tr>     <th align=left>key</th>     <th align=left>Example Value</th>     <th align=left>Description</th>   </tr>   <tr>     <td>`api-key`</td>     <td>api-key-provided-by-emass</td>     <td>This API key must be provided in the request header for all endpoint calls</td>   </tr>   <tr>     <td>`user-uid`</td>     <td>USER.UID.KEY</td>     <td>This User unique identifier key must be provided in the request header for all PUT, POST, and DELETE endpoint calls</td>   </tr>   <tr>     <td></td><td></td>     <td>       Note: For DoD users this is the DoD ID Number (EIDIPI) on their DoD CAC     </td>   </tr> </table>  </br><strong>Approve API Client for Actionable Requests</strong></br> Users are required to log-in to eMASS and grant permissions for a client to update data within eMASS on their behalf. This is only required for actionable requests (PUT, POST, DELETE). The Registration Endpoint and all GET requests can be accessed without completing this process with the correct permissions. Please note that leaving a field parameter blank (for PUT/POST requests) has the potential to clear information in the active eMASS records.  To establish an account with eMASS and/or acquire an api-key/user-uid, contact one of the listed POC: 

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v3.2
- Package version: 1.0.1
- Build package: io.swagger.codegen.v3.generators.ruby.RubyClientCodegen
For more information, please visit [https://www.dcsa.mil/is/emass/](https://www.dcsa.mil/is/emass/)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build emass_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./emass_client-1.0.1.gem
```
(for development, run `gem install --dev ./emass_client-1.0.1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'emass_client', '~> 1.0.1'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'emass_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'emass_client'
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::ArtifactsApi.new
is_template = true # BOOLEAN | 
type = 'type_example' # String | 
category = 'category_example' # String | 
zipper = 'zipper_example' # String | 
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Add one or many artifacts in a system
  result = api_instance.add_artifacts_by_system_id(is_template, type, category, zipper, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling ArtifactsApi->add_artifacts_by_system_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::ArtifactsApi.new
body = [EmassClient::ArtifactsDeleteInner.new] # Array<ArtifactsDeleteInner> | See notes above for additional information
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Remove one or many artifacts in a system
  result = api_instance.delete_artifact(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling ArtifactsApi->delete_artifact: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::ArtifactsApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
opts = { 
  filename: 'filename_example', # String | **File Name**: The file name (to include file-extension).
  control_acronyms: 'control_acronyms_example', # String | **System Acronym**: Filter query by given system acronym (single or comma separated).
  ccis: 'ccis_example', # String | **CCI System**: Filter query by Control Correlation Identifiers (CCIs).
  system_only: true # BOOLEAN | **Systems Only**: Indicates that only system(s) information is retrieved.
}

begin
  #Get one or many artifacts in a system
  result = api_instance.get_system_artifacts(system_id, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling ArtifactsApi->get_system_artifacts: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::ArtifactsApi.new
body = EmassClient::ArtifactsRequestPutBody.new # ArtifactsRequestPutBody | See `information` above for additional instructions
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Update one or many artifacts in a system
  result = api_instance.update_artifact_by_system_id(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling ArtifactsApi->update_artifact_by_system_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::ArtifactsExportApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
filename = 'filename_example' # String | **File Name**: The file name (to include file-extension).
opts = { 
  compress: true # BOOLEAN | **Compress File**: Determines if returned file is compressed.
}

begin
  #Get the file of an artifact in a system
  result = api_instance.get_system_artifacts_export(system_id, filename, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling ArtifactsExportApi->get_system_artifacts_export: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::CACApi.new
body = EmassClient::CacRequestPostBody.new # CacRequestPostBody | Update an existing Artifact by Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Submit control to second role of CAC
  result = api_instance.add_system_cac(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling CACApi->add_system_cac: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::CACApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
opts = { 
  control_acronyms: 'control_acronyms_example' # String | **System Acronym**: Filter query by given system acronym (single or comma separated).
}

begin
  #Get location of one or many controls in CAC
  result = api_instance.get_system_cac(system_id, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling CACApi->get_system_cac: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::CMMCAssessmentsApi.new
since_date = 'since_date_example' # String | **Date** CMMC date (Unix date format)


begin
  #Get CMMC assessment information
  result = api_instance.get_cmmc_assessments(since_date)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling CMMCAssessmentsApi->get_cmmc_assessments: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::ControlsApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
opts = { 
  acronyms: 'PM-6' # String | **Acronym**: The system acronym(s) being queried (single value or comma delimited values).
}

begin
  #Get control information in a system for one or many controls
  result = api_instance.get_system_controls(system_id, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling ControlsApi->get_system_controls: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::ControlsApi.new
body = EmassClient::ControlsRequestPutBody.new # ControlsRequestPutBody | Update an existing control by Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Update control information in a system for one or many controls
  result = api_instance.update_control_by_system_id(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling ControlsApi->update_control_by_system_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::MilestonesApi.new
body = EmassClient::MilestonesRequestPostBody.new # MilestonesRequestPostBody | Update an existing milestone
system_id = 56 # Integer | **System Id**: The unique system record identifier.
poam_id = 56 # Integer | **POA&M Id**: The unique POA&M record identifier.


begin
  #Add milestones to one or many POA&M items in a system
  result = api_instance.add_milestone_by_system_id_and_poam_id(body, system_id, poam_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling MilestonesApi->add_milestone_by_system_id_and_poam_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::MilestonesApi.new
body = EmassClient::DeleteMilestone.new # DeleteMilestone | Delete the given Milestone Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.
poam_id = 56 # Integer | **POA&M Id**: The unique POA&M record identifier.


begin
  #Remove milestones in a system for one or many POA&M items
  result = api_instance.delete_milestone(body, system_id, poam_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling MilestonesApi->delete_milestone: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::MilestonesApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
poam_id = 56 # Integer | **POA&M Id**: The unique POA&M record identifier.
opts = { 
  scheduled_completion_date_start: 'scheduled_completion_date_start_example', # String | **Date Started**: Filter query by the scheduled completion start date (Unix date format).
  scheduled_completion_date_end: 'scheduled_completion_date_end_example' # String | **Date Ended**: Filter query by the scheduled completion start date (Unix date format).
}

begin
  #Get milestones in one or many POA&M items in a system
  result = api_instance.get_system_milestones_by_poam_id(system_id, poam_id, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling MilestonesApi->get_system_milestones_by_poam_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::MilestonesApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
poam_id = 56 # Integer | **POA&M Id**: The unique POA&M record identifier.
milestone_id = 56 # Integer | **Milestone Id**: The unique milestone record identifier.


begin
  #Get milestone by ID in POA&M item in a system
  result = api_instance.get_system_milestones_by_poam_id_and_milestone_id(system_id, poam_id, milestone_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling MilestonesApi->get_system_milestones_by_poam_id_and_milestone_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::MilestonesApi.new
body = EmassClient::MilestonesRequestPutBody.new # MilestonesRequestPutBody | Update an existing control by Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.
poam_id = 56 # Integer | **POA&M Id**: The unique POA&M record identifier.


begin
  #Update one or many POA&M items in a system
  result = api_instance.update_milestone_by_system_id_and_poam_id(body, system_id, poam_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling MilestonesApi->update_milestone_by_system_id_and_poam_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::PACApi.new
body = EmassClient::PacRequestPostBody.new # PacRequestPostBody | Update an existing Artifact by Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Submit system package for review
  result = api_instance.add_system_pac(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling PACApi->add_system_pac: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::PACApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Get location of system package in PAC
  result = api_instance.get_system_pac(system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling PACApi->get_system_pac: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::POAMApi.new
body = EmassClient::PoamRequiredPost.new # PoamRequiredPost | Update an existing control by Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Add one or many POA&M items in a system
  result = api_instance.add_poam_by_system_id(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling POAMApi->add_poam_by_system_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::POAMApi.new
body = EmassClient::DeletePoam.new # DeletePoam | Delete the given POA&M Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Remove one or many POA&M items in a system
  result = api_instance.delete_poam(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling POAMApi->delete_poam: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::POAMApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
opts = { 
  scheduled_completion_date_start: 'scheduled_completion_date_start_example', # String | **Date Started**: Filter query by the scheduled completion start date (Unix date format).
  scheduled_completion_date_end: 'scheduled_completion_date_end_example', # String | **Date Ended**: Filter query by the scheduled completion start date (Unix date format).
  control_acronyms: 'control_acronyms_example', # String | **System Acronym**: Filter query by given system acronym (single or comma separated).
  ccis: 'ccis_example', # String | **CCI System**: Filter query by Control Correlation Identifiers (CCIs).
  system_only: true # BOOLEAN | **Systems Only**: Indicates that only system(s) information is retrieved.
}

begin
  #Get one or many POA&M items in a system
  result = api_instance.get_system_poams(system_id, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling POAMApi->get_system_poams: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::POAMApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
poam_id = 56 # Integer | **POA&M Id**: The unique POA&M record identifier.


begin
  #Get POA&M item by ID in a system
  result = api_instance.get_system_poams_by_poam_id(system_id, poam_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling POAMApi->get_system_poams_by_poam_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::POAMApi.new
body = EmassClient::PoamRequiredPut.new # PoamRequiredPut | Update an existing control by Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Update one or many POA&M items in a system
  result = api_instance.update_poam_by_system_id(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling POAMApi->update_poam_by_system_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::RegistrationApi.new
body = EmassClient::RegisterUserRequestPostBody.new # RegisterUserRequestPostBody | User certificate previously provided by eMASS.


begin
  #Register user certificate and obtain an API key
  result = api_instance.register_user(body)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling RegistrationApi->register_user: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::StaticCodeScansApi.new
body = EmassClient::StaticCodeRequiredPost.new # StaticCodeRequiredPost | Update an existing Artifact by Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Upload static code scans or Clear static code scans
  result = api_instance.add_static_code_scans_by_system_id(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling StaticCodeScansApi->add_static_code_scans_by_system_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::SystemRolesApi.new

begin
  #Get available roles
  result = api_instance.get_system_roles
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling SystemRolesApi->get_system_roles: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::SystemRolesApi.new
role_category = 'role_category_example' # String | **Role Category**: The system role category been queried
role = 'IAO' # String | **Role**: Accepts single value from options available at base system-roles endpoint e.g., SCA.
opts = { 
  policy: 'rmf', # String | **System Policy**: Filter query by system policy. If no value is specified and more than one policy is available, the default return is the RMF policy information.
  include_decommissioned: true # BOOLEAN | **Include Decommissioned Systems**: Indicates if decommissioned systems are retrieved. If no value is specified, the default returns true to include decommissioned systems.
}

begin
  #Get system roles
  result = api_instance.get_system_roles_by_category_id(role_category, role, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling SystemRolesApi->get_system_roles_by_category_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::SystemsApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
opts = { 
  include_package: true, # BOOLEAN | **Include Package**:  Indicates if additional packages information is retrieved for queried system.
  policy: 'rmf' # String | **System Policy**: Filter query by system policy. If no value is specified and more than one policy is available, the default return is the RMF policy information.
}

begin
  #Get system information for a specific system
  result = api_instance.get_system(system_id, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling SystemsApi->get_system: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::SystemsApi.new
opts = { 
  include_package: true, # BOOLEAN | **Include Package**:  Indicates if additional packages information is retrieved for queried system.
  registration_type: 'regular', # String | **Registration Type**: Filter record by selected registration type (single value or comma delimited values).  *Available values:* assessAndAuthorize, assessOnly, guest, regular, functional, cloudServiceProvider, commonControlProvider  
  ditpr_id: 'ditpr_id_example', # String | **DITPR ID**: Filter query by DoD Information Technology (IT) Portfolio Repository (DITPR).
  coams_id: 'coams_id_example', # String | **COAMS ID**: Filter query by Cyber Operational Attributes Management System (COAMS).
  policy: 'rmf', # String | **System Policy**: Filter query by system policy. If no value is specified and more than one policy is available, the default return is the RMF policy information.
  include_ditpr_metrics: false, # BOOLEAN | **Include DITPR**: Indicates if DITPR metrics are retrieved. This query string parameter can only be used in conjunction with the following parameters:<br>   <ul>     <li>registrationType</li>     <li>policy</li>   </ul>
  include_decommissioned: true, # BOOLEAN | **Include Decommissioned Systems**: Indicates if decommissioned systems are retrieved. If no value is specified, the default returns true to include decommissioned systems.
  reports_for_scorecard: true # BOOLEAN | **DoD Cyber Hygiene Scorecard**: Indicates if the system reports to the DoD Cyber Hygiene Scorecard.
}

begin
  #Get system information
  result = api_instance.get_systems(opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling SystemsApi->get_systems: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::TestApi.new

begin
  #Test connection to the API
  result = api_instance.test_connection
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling TestApi->test_connection: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::TestResultsApi.new
body = EmassClient::TestResultsRequestPostBody.new # TestResultsRequestPostBody | Update an existing control by Id
system_id = 56 # Integer | **System Id**: The unique system record identifier.


begin
  #Add one or many test results in a system
  result = api_instance.add_test_results_by_system_id(body, system_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling TestResultsApi->add_test_results_by_system_id: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::TestResultsApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
opts = { 
  control_acronyms: 'control_acronyms_example', # String | **System Acronym**: Filter query by given system acronym (single or comma separated).
  ccis: 'ccis_example', # String | **CCI System**: Filter query by Control Correlation Identifiers (CCIs).
  latest_only: true # BOOLEAN | **Latest Results Only**: Indicates that only the latest test resultes are retrieved (single or comma separated).
}

begin
  #Get one or many test results in a system
  result = api_instance.get_system_test_results(system_id, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling TestResultsApi->get_system_test_results: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::WorkflowDefinitionsApi.new
opts = { 
  include_inactive: true, # BOOLEAN | **Include Inactive**: If no value is specified, the default returns false to not include outdated workflow definitions.
  registration_type: 'regular' # String | **Registration Type**: Filter record by selected registration type (single value or comma delimited values).  *Available values:* assessAndAuthorize, assessOnly, guest, regular, functional, cloudServiceProvider, commonControlProvider  
}

begin
  #Get workflow definitions in a site
  result = api_instance.get_workflow_definitions(opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling WorkflowDefinitionsApi->get_workflow_definitions: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::WorkflowInstancesApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
opts = { 
  include_comments: true, # BOOLEAN | **Include Comments**: If no value is specified, the default returns true to not include transition comments.  Note: Corresponds to the Comments textbox that is required at most workflow transitions. Does not include other text input fields such as Terms / Conditions for Authorization. 
  page_index: 0, # Integer | **Page Index**: If no value is specified, the default returns true to not include transition comments.
  since_date: 'since_date_example', # String | **Date**: Filter on authorization/assessment date (Unix date format).  Note: Filters off the lastEditedDate field.  Note: The authorization/assessment decisions on completed workflows  can be edited for up to 30 days after the initial decision is made. 
  status: 'all' # String | **Status**: Filter by status.  If no value is specified, the default returns all to include both active and inactive workflows.  Note: Any workflows at a current stage of Complete or Cancelled are inactive. Ongoing workflows currently at other stages are active. 
}

begin
  #Get workflow instances in a system
  result = api_instance.get_system_workflow_instances(system_id, opts)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling WorkflowInstancesApi->get_system_workflow_instances: #{e}"
end
# Setup authorization
EmassClient.configure do |config|
  # Configure API key authorization: apikey
  config.api_key['api-key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-key'] = 'Bearer'

  # Configure API key authorization: mockType
  config.api_key['Prefer'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Prefer'] = 'Bearer'

  # Configure API key authorization: userid
  config.api_key['user-uid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['user-uid'] = 'Bearer'
end

api_instance = EmassClient::WorkflowInstancesApi.new
system_id = 56 # Integer | **System Id**: The unique system record identifier.
workflow_instance_id = 56 # Integer | **Workflow Instance Id**: The unique milestone record identifier.


begin
  #Get workflow instance by ID in a system
  result = api_instance.get_system_workflow_instances_by_workflow_instance_id(system_id, workflow_instance_id)
  p result
rescue EmassClient::ApiError => e
  puts "Exception when calling WorkflowInstancesApi->get_system_workflow_instances_by_workflow_instance_id: #{e}"
end
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:4010*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*EmassClient::ArtifactsApi* | [**add_artifacts_by_system_id**](docs/ArtifactsApi.md#add_artifacts_by_system_id) | **POST** /api/systems/{systemId}/artifacts | Add one or many artifacts in a system
*EmassClient::ArtifactsApi* | [**delete_artifact**](docs/ArtifactsApi.md#delete_artifact) | **DELETE** /api/systems/{systemId}/artifacts | Remove one or many artifacts in a system
*EmassClient::ArtifactsApi* | [**get_system_artifacts**](docs/ArtifactsApi.md#get_system_artifacts) | **GET** /api/systems/{systemId}/artifacts | Get one or many artifacts in a system
*EmassClient::ArtifactsApi* | [**update_artifact_by_system_id**](docs/ArtifactsApi.md#update_artifact_by_system_id) | **PUT** /api/systems/{systemId}/artifacts | Update one or many artifacts in a system
*EmassClient::ArtifactsExportApi* | [**get_system_artifacts_export**](docs/ArtifactsExportApi.md#get_system_artifacts_export) | **GET** /api/systems/{systemId}/artifacts-export | Get the file of an artifact in a system
*EmassClient::CACApi* | [**add_system_cac**](docs/CACApi.md#add_system_cac) | **POST** /api/systems/{systemId}/approval/cac | Submit control to second role of CAC
*EmassClient::CACApi* | [**get_system_cac**](docs/CACApi.md#get_system_cac) | **GET** /api/systems/{systemId}/approval/cac | Get location of one or many controls in CAC
*EmassClient::CMMCAssessmentsApi* | [**get_cmmc_assessments**](docs/CMMCAssessmentsApi.md#get_cmmc_assessments) | **GET** /api/cmmc-assessments | Get CMMC assessment information
*EmassClient::ControlsApi* | [**get_system_controls**](docs/ControlsApi.md#get_system_controls) | **GET** /api/systems/{systemId}/controls | Get control information in a system for one or many controls
*EmassClient::ControlsApi* | [**update_control_by_system_id**](docs/ControlsApi.md#update_control_by_system_id) | **PUT** /api/systems/{systemId}/controls | Update control information in a system for one or many controls
*EmassClient::MilestonesApi* | [**add_milestone_by_system_id_and_poam_id**](docs/MilestonesApi.md#add_milestone_by_system_id_and_poam_id) | **POST** /api/systems/{systemId}/poams/{poamId}/milestones | Add milestones to one or many POA&M items in a system
*EmassClient::MilestonesApi* | [**delete_milestone**](docs/MilestonesApi.md#delete_milestone) | **DELETE** /api/systems/{systemId}/poams/{poamId}/milestones | Remove milestones in a system for one or many POA&M items
*EmassClient::MilestonesApi* | [**get_system_milestones_by_poam_id**](docs/MilestonesApi.md#get_system_milestones_by_poam_id) | **GET** /api/systems/{systemId}/poams/{poamId}/milestones | Get milestones in one or many POA&M items in a system
*EmassClient::MilestonesApi* | [**get_system_milestones_by_poam_id_and_milestone_id**](docs/MilestonesApi.md#get_system_milestones_by_poam_id_and_milestone_id) | **GET** /api/systems/{systemId}/poams/{poamId}/milestones/{milestoneId} | Get milestone by ID in POA&M item in a system
*EmassClient::MilestonesApi* | [**update_milestone_by_system_id_and_poam_id**](docs/MilestonesApi.md#update_milestone_by_system_id_and_poam_id) | **PUT** /api/systems/{systemId}/poams/{poamId}/milestones | Update one or many POA&M items in a system
*EmassClient::PACApi* | [**add_system_pac**](docs/PACApi.md#add_system_pac) | **POST** /api/systems/{systemId}/approval/pac | Submit system package for review
*EmassClient::PACApi* | [**get_system_pac**](docs/PACApi.md#get_system_pac) | **GET** /api/systems/{systemId}/approval/pac | Get location of system package in PAC
*EmassClient::POAMApi* | [**add_poam_by_system_id**](docs/POAMApi.md#add_poam_by_system_id) | **POST** /api/systems/{systemId}/poams | Add one or many POA&M items in a system
*EmassClient::POAMApi* | [**delete_poam**](docs/POAMApi.md#delete_poam) | **DELETE** /api/systems/{systemId}/poams | Remove one or many POA&M items in a system
*EmassClient::POAMApi* | [**get_system_poams**](docs/POAMApi.md#get_system_poams) | **GET** /api/systems/{systemId}/poams | Get one or many POA&M items in a system
*EmassClient::POAMApi* | [**get_system_poams_by_poam_id**](docs/POAMApi.md#get_system_poams_by_poam_id) | **GET** /api/systems/{systemId}/poams/{poamId} | Get POA&M item by ID in a system
*EmassClient::POAMApi* | [**update_poam_by_system_id**](docs/POAMApi.md#update_poam_by_system_id) | **PUT** /api/systems/{systemId}/poams | Update one or many POA&M items in a system
*EmassClient::RegistrationApi* | [**register_user**](docs/RegistrationApi.md#register_user) | **POST** /api/api-key | Register user certificate and obtain an API key
*EmassClient::StaticCodeScansApi* | [**add_static_code_scans_by_system_id**](docs/StaticCodeScansApi.md#add_static_code_scans_by_system_id) | **POST** /api/systems/{systemId}/static-code-scans | Upload static code scans or Clear static code scans
*EmassClient::SystemRolesApi* | [**get_system_roles**](docs/SystemRolesApi.md#get_system_roles) | **GET** /api/system-roles | Get available roles
*EmassClient::SystemRolesApi* | [**get_system_roles_by_category_id**](docs/SystemRolesApi.md#get_system_roles_by_category_id) | **GET** /api/system-roles/{roleCategory} | Get system roles
*EmassClient::SystemsApi* | [**get_system**](docs/SystemsApi.md#get_system) | **GET** /api/systems/{systemId} | Get system information for a specific system
*EmassClient::SystemsApi* | [**get_systems**](docs/SystemsApi.md#get_systems) | **GET** /api/systems | Get system information
*EmassClient::TestApi* | [**test_connection**](docs/TestApi.md#test_connection) | **GET** /api | Test connection to the API
*EmassClient::TestResultsApi* | [**add_test_results_by_system_id**](docs/TestResultsApi.md#add_test_results_by_system_id) | **POST** /api/systems/{systemId}/test-results | Add one or many test results in a system
*EmassClient::TestResultsApi* | [**get_system_test_results**](docs/TestResultsApi.md#get_system_test_results) | **GET** /api/systems/{systemId}/test-results | Get one or many test results in a system
*EmassClient::WorkflowDefinitionsApi* | [**get_workflow_definitions**](docs/WorkflowDefinitionsApi.md#get_workflow_definitions) | **GET** /api/workflow-definitions | Get workflow definitions in a site
*EmassClient::WorkflowInstancesApi* | [**get_system_workflow_instances**](docs/WorkflowInstancesApi.md#get_system_workflow_instances) | **GET** /api/systems/{systemId}/workflow-instances | Get workflow instances in a system
*EmassClient::WorkflowInstancesApi* | [**get_system_workflow_instances_by_workflow_instance_id**](docs/WorkflowInstancesApi.md#get_system_workflow_instances_by_workflow_instance_id) | **GET** /api/systems/{systemId}/workflow-instances/{workflowInstanceId} | Get workflow instance by ID in a system

## Documentation for Models

 - [EmassClient::ArtifactsDelete](docs/ArtifactsDelete.md)
 - [EmassClient::ArtifactsDeleteInner](docs/ArtifactsDeleteInner.md)
 - [EmassClient::ArtifactsGet](docs/ArtifactsGet.md)
 - [EmassClient::ArtifactsRequestPutBody](docs/ArtifactsRequestPutBody.md)
 - [EmassClient::ArtifactsResponseDel](docs/ArtifactsResponseDel.md)
 - [EmassClient::ArtifactsResponseDelData](docs/ArtifactsResponseDelData.md)
 - [EmassClient::ArtifactsResponseGet](docs/ArtifactsResponseGet.md)
 - [EmassClient::ArtifactsResponsePutPost](docs/ArtifactsResponsePutPost.md)
 - [EmassClient::CacGet](docs/CacGet.md)
 - [EmassClient::CacRequestPostBody](docs/CacRequestPostBody.md)
 - [EmassClient::CacResponseGet](docs/CacResponseGet.md)
 - [EmassClient::CacResponsePost](docs/CacResponsePost.md)
 - [EmassClient::CacResponsePostData](docs/CacResponsePostData.md)
 - [EmassClient::CmmcGet](docs/CmmcGet.md)
 - [EmassClient::CmmcResponseGet](docs/CmmcResponseGet.md)
 - [EmassClient::ConnectivityCcsd](docs/ConnectivityCcsd.md)
 - [EmassClient::ControlsGet](docs/ControlsGet.md)
 - [EmassClient::ControlsPut](docs/ControlsPut.md)
 - [EmassClient::ControlsRequestPutBody](docs/ControlsRequestPutBody.md)
 - [EmassClient::ControlsResponseGet](docs/ControlsResponseGet.md)
 - [EmassClient::ControlsResponsePut](docs/ControlsResponsePut.md)
 - [EmassClient::DefinitionTransitions](docs/DefinitionTransitions.md)
 - [EmassClient::DeleteMilestone](docs/DeleteMilestone.md)
 - [EmassClient::DeletePoam](docs/DeletePoam.md)
 - [EmassClient::Empty200Response](docs/Empty200Response.md)
 - [EmassClient::Error](docs/Error.md)
 - [EmassClient::InstancesTransitions](docs/InstancesTransitions.md)
 - [EmassClient::MilestoneResponseGet](docs/MilestoneResponseGet.md)
 - [EmassClient::MilestoneResponsePost](docs/MilestoneResponsePost.md)
 - [EmassClient::MilestoneResponsePut](docs/MilestoneResponsePut.md)
 - [EmassClient::MilestonesDelete](docs/MilestonesDelete.md)
 - [EmassClient::MilestonesGet](docs/MilestonesGet.md)
 - [EmassClient::MilestonesPost](docs/MilestonesPost.md)
 - [EmassClient::MilestonesPut](docs/MilestonesPut.md)
 - [EmassClient::MilestonesPutPostDelete](docs/MilestonesPutPostDelete.md)
 - [EmassClient::MilestonesRequestPostBody](docs/MilestonesRequestPostBody.md)
 - [EmassClient::MilestonesRequestPutBody](docs/MilestonesRequestPutBody.md)
 - [EmassClient::MilestonesRequiredPost](docs/MilestonesRequiredPost.md)
 - [EmassClient::MilestonesRequiredPut](docs/MilestonesRequiredPut.md)
 - [EmassClient::Model200](docs/Model200.md)
 - [EmassClient::Model201](docs/Model201.md)
 - [EmassClient::Model201Meta](docs/Model201Meta.md)
 - [EmassClient::Model400](docs/Model400.md)
 - [EmassClient::Model400Meta](docs/Model400Meta.md)
 - [EmassClient::Model400Response](docs/Model400Response.md)
 - [EmassClient::Model401](docs/Model401.md)
 - [EmassClient::Model401Meta](docs/Model401Meta.md)
 - [EmassClient::Model403](docs/Model403.md)
 - [EmassClient::Model403Meta](docs/Model403Meta.md)
 - [EmassClient::Model404](docs/Model404.md)
 - [EmassClient::Model404Response](docs/Model404Response.md)
 - [EmassClient::Model405](docs/Model405.md)
 - [EmassClient::Model405Meta](docs/Model405Meta.md)
 - [EmassClient::Model411](docs/Model411.md)
 - [EmassClient::Model411Meta](docs/Model411Meta.md)
 - [EmassClient::Model490](docs/Model490.md)
 - [EmassClient::Model490Meta](docs/Model490Meta.md)
 - [EmassClient::Model500](docs/Model500.md)
 - [EmassClient::Model500Meta](docs/Model500Meta.md)
 - [EmassClient::PacGet](docs/PacGet.md)
 - [EmassClient::PacPost](docs/PacPost.md)
 - [EmassClient::PacRequestPostBody](docs/PacRequestPostBody.md)
 - [EmassClient::PacResponseGet](docs/PacResponseGet.md)
 - [EmassClient::PacResponsePost](docs/PacResponsePost.md)
 - [EmassClient::PoamDelete](docs/PoamDelete.md)
 - [EmassClient::PoamGet](docs/PoamGet.md)
 - [EmassClient::PoamPost](docs/PoamPost.md)
 - [EmassClient::PoamPostPutDel](docs/PoamPostPutDel.md)
 - [EmassClient::PoamPut](docs/PoamPut.md)
 - [EmassClient::PoamRequestPostBody](docs/PoamRequestPostBody.md)
 - [EmassClient::PoamRequestPutBody](docs/PoamRequestPutBody.md)
 - [EmassClient::PoamRequiredPost](docs/PoamRequiredPost.md)
 - [EmassClient::PoamRequiredPut](docs/PoamRequiredPut.md)
 - [EmassClient::PoamResponseDelete](docs/PoamResponseDelete.md)
 - [EmassClient::PoamResponseGet](docs/PoamResponseGet.md)
 - [EmassClient::PoamResponsePost](docs/PoamResponsePost.md)
 - [EmassClient::PoamResponsePut](docs/PoamResponsePut.md)
 - [EmassClient::Register](docs/Register.md)
 - [EmassClient::RegisterData](docs/RegisterData.md)
 - [EmassClient::RegisterUserRequestPostBody](docs/RegisterUserRequestPostBody.md)
 - [EmassClient::RoleCategory](docs/RoleCategory.md)
 - [EmassClient::Roles](docs/Roles.md)
 - [EmassClient::Ssps](docs/Ssps.md)
 - [EmassClient::Stage](docs/Stage.md)
 - [EmassClient::StaticCodeApplication](docs/StaticCodeApplication.md)
 - [EmassClient::StaticCodeRequestPostBody](docs/StaticCodeRequestPostBody.md)
 - [EmassClient::StaticCodeRequiredPost](docs/StaticCodeRequiredPost.md)
 - [EmassClient::StaticCodeRequiredPostApplication](docs/StaticCodeRequiredPostApplication.md)
 - [EmassClient::Success200Response](docs/Success200Response.md)
 - [EmassClient::SystemIdArtifactsBody](docs/SystemIdArtifactsBody.md)
 - [EmassClient::SystemResponse](docs/SystemResponse.md)
 - [EmassClient::SystemRolesCategoryResponse](docs/SystemRolesCategoryResponse.md)
 - [EmassClient::SystemRolesResponse](docs/SystemRolesResponse.md)
 - [EmassClient::SystemRolesResponseData](docs/SystemRolesResponseData.md)
 - [EmassClient::Systems](docs/Systems.md)
 - [EmassClient::Test](docs/Test.md)
 - [EmassClient::TestData](docs/TestData.md)
 - [EmassClient::TestResultsGet](docs/TestResultsGet.md)
 - [EmassClient::TestResultsPost](docs/TestResultsPost.md)
 - [EmassClient::TestResultsRequestPostBody](docs/TestResultsRequestPostBody.md)
 - [EmassClient::TestResultsResponseGet](docs/TestResultsResponseGet.md)
 - [EmassClient::TestResultsResponsePost](docs/TestResultsResponsePost.md)
 - [EmassClient::Users](docs/Users.md)
 - [EmassClient::WorkflowDefinitionGet](docs/WorkflowDefinitionGet.md)
 - [EmassClient::WorkflowDefinitionResponseGet](docs/WorkflowDefinitionResponseGet.md)
 - [EmassClient::WorkflowInstancesGet](docs/WorkflowInstancesGet.md)
 - [EmassClient::WorkflowInstancesResponseGet](docs/WorkflowInstancesResponseGet.md)

## Documentation for Authorization


### apikey

- **Type**: API key
- **API key parameter name**: api-key
- **Location**: HTTP header

### mockType

- **Type**: API key
- **API key parameter name**: Prefer
- **Location**: HTTP header

### userid

- **Type**: API key
- **API key parameter name**: user-uid
- **Location**: HTTP header

